@@ -1,6 +1,6 @@
 package Map::Tube::Line;
 
-$Map::Tube::Line::VERSION   = '4.08';
+$Map::Tube::Line::VERSION   = '4.09';
 $Map::Tube::Line::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,12 +9,11 @@ Map::Tube::Line - Class to represent the line in the map.
 
 =head1 VERSION
 
-Version 4.08
+Version 4.09
 
 =cut
 
-use 5.006;
-use Data::Dumper;
+use v5.14;
 
 use Map::Tube::Exception::MissingNodeObject;
 use Map::Tube::Exception::InvalidNodeObject;
